summaryrefslogtreecommitdiff
path: root/java/sql/BatchUpdateException.java
diff options
context:
space:
mode:
authorBryce McKinlay <mckinlay@redhat.com>2002-06-21 05:34:11 +0000
committerBryce McKinlay <mckinlay@redhat.com>2002-06-21 05:34:11 +0000
commite6310144dfb9c26e957cf5fc1bce338949701b3c (patch)
treee4d7695f13ba10c21a2ddcbb912b865954627db7 /java/sql/BatchUpdateException.java
parent1b1211e7e94c0d19d2df89c565016ff6cd260969 (diff)
downloadclasspath-e6310144dfb9c26e957cf5fc1bce338949701b3c.tar.gz
Reformat JDBC classes and add new JDK 1.4 classes and methods.
* java/sql/ParameterMetaData.java, java/sql/SQLPermission.java, java/sql/Savepoint.java: New files. * java/sql/Array.java, java/sql/BatchUpdateException.java, java/sql/Blob.java, java/sql/CallableStatement.java, java/sql/Clob.java, java/sql/Connection.java, java/sql/DataTruncation.java, java/sql/DatabaseMetaData.java, java/sql/Date.java, java/sql/Driver.java, java/sql/DriverManager.java, java/sql/DriverPropertyInfo.java, java/sql/PreparedStatement.java, java/sql/Ref.java, java/sql/ResultSet.java, java/sql/ResultSetMetaData.java, java/sql/SQLData.java java/sql/SQLException.java, java/sql/SQLInput.java, java/sql/SQLOutput.java, java/sql/SQLWarning.java java/sql/Statement.java, java/sql/Struct.java, java/sql/Time.java, java/sql/Timestamp.java, java/sql/Types.java: Updated to JDBC 3.0 (JDK 1.4) specification. * javax/sql/ConnectionEvent.java, javax/sql/ConnectionEventListener.java, javax/sql/ConnectionPoolDataSource.java, javax/sql/DataSource.java, javax/sql/PooledConnection.java, javax/sql/RowSetEvent.java, javax/sql/RowSetInternal.java, javax/sql/RowSet.java, javax/sql/RowSetListener.java, javax/sql/RowSetMetaData.java, javax/sql/RowSetReader.java, javax/sql/RowSetWriter.java, javax/sql/XAConnection.java, javax/sql/XADataSource.java: New files. * java/sql/Makefile.am: Add new files. * javax/sql/Makefile.am: New. * javax/sql/package.html: New.
Diffstat (limited to 'java/sql/BatchUpdateException.java')
-rw-r--r--java/sql/BatchUpdateException.java114
1 files changed, 54 insertions, 60 deletions
diff --git a/java/sql/BatchUpdateException.java b/java/sql/BatchUpdateException.java
index ead198e99..515f1d466 100644
--- a/java/sql/BatchUpdateException.java
+++ b/java/sql/BatchUpdateException.java
@@ -1,4 +1,4 @@
-/* BatchUpdateException.java -- exception for batch oriented SQL errors
+/* BatchUpdateException.java -- Exception for batch oriented SQL errors
Copyright (C) 1999, 2000, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -7,7 +7,7 @@ GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
-
+
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
@@ -35,113 +35,107 @@ this exception to your version of the library, but you are not
obligated to do so. If you do not wish to do so, delete this
exception statement from your version. */
-
package java.sql;
/**
* This class extends <code>SQLException</code> to count the successful
- * updates in each statement in a batch that was successfully updated prior
- * to the error. The driver may continue to process batch commands, in which
- * case those commands also have an entry in the array. So, to tell which
- * command failed, search for <code>Statement.EXECUTE_FAILED</code>.
+ * updates in each statement in a batch that was successfully updated prior
+ * to the error.
*
* @author Aaron M. Renn (arenn@urbanophile.com)
- * @since 1.2
- * @status updated to 1.4
*/
-public class BatchUpdateException extends SQLException
+public class BatchUpdateException extends SQLException
{
- /**
- * Compatible with JDK 1.2+.
- */
- private static final long serialVersionUID = 5977529877145521757L;
+ static final long serialVersionUID = 5977529877145521757L;
/**
* This is the array of update counts for the commands which completed
* successfully prior to the error.
- *
- * @serial the outcome of the batch execution
*/
- private final int[] updateCounts;
+ private int[] updateCounts;
/**
* Create a new instance with no descriptive error message. The SQL state
* and update count will be initialized to <code>null</code> and the
* vendor specific error code will initialized to 0.
*/
- public BatchUpdateException()
+ public BatchUpdateException(String message, String SQLState, int vendorCode,
+ int[] updateCounts)
{
- this(null, null, 0, null);
+ super(message, SQLState, vendorCode);
+ this.updateCounts = updateCounts;
}
/**
- * Create a new instance with the specified update count information and
- * no descriptive error message. This SQL state will be initialized to
- * <code>null</code> and the vendor specific error code will be initialized
- * to 0.
+ * This method initializes a new instance of <code>BatchUpdateException</code>
+ * with the specified descriptive error message, SQL state, and update count
+ * information. The vendor specific error code will be initialized to 0.
*
- * @param updateCounts the update count array
+ * @param message The descriptive error message.
+ * @param SQLState The SQL state information for this error.
+ * @param updateCounts The update count information for this error.
*/
- public BatchUpdateException(int[] updateCounts)
+ public BatchUpdateException(String message, String SQLState,
+ int[] updateCounts)
{
- this(null, null, 0, updateCounts);
+ super(message, SQLState);
+ this.updateCounts = updateCounts;
}
/**
- * Create a new instance with the specified descriptive error message and
- * update count information. The SQL state will be initialized to
- * <code>null</code> and the vendor specific error code will be
- * initialized to 0.
+ * This method initializes a new instance of <code>BatchUpdateException</code>
+ * with the specified descriptive error message and update count information.
+ * The SQL state will be initialized to <code>null</code> and the vendor
+ * specific error code will be initialized to 0.
*
- * @param message the descriptive error message
- * @param updateCounts the update count information for this error
+ * @param message The descriptive error message.
+ * @param updateCounts The update count information for this error.
*/
public BatchUpdateException(String message, int[] updateCounts)
{
- this(message, null, 0, updateCounts);
+ super(message);
+ this.updateCounts = updateCounts;
}
/**
- * Create a new instance with the specified descriptive error message,
- * SQL state, and update count information. The vendor specific error
- * code will be initialized to 0.
+ * Initializes a new instance of <code>BatchUpdateException</code>
+ * with the specified update count information and no descriptive error
+ * message. This SQL state will be initialized to <code>null</code> and
+ * the vendor specific error code will be initialized to 0.
*
- * @param message the descriptive error message
- * @param state the SQL state information for this error
- * @param updateCounts the update count information for this error
+ * @param updateCounts The update count array.
*/
- public BatchUpdateException(String message, String state,
- int[] updateCounts)
+ public BatchUpdateException(int[] updateCounts)
{
- this(message, state, 0, updateCounts);
+ this.updateCounts = updateCounts;
}
/**
- * Create a new instance with the specified descriptive error message,
- * SQL state, vendor specific error code and update count information.
- *
- * @param message the descriptive error message
- * @param state the SQL state information for this error
- * @param vendorCode the vendor specific error code for this error
- * @param updateCounts the update count information for this error
+ * Initializes a new instance of <code>BatchUpdateException</code>
+ * with no descriptive error message. The SQL state and update count will
+ * be initialized to <code>null</code> and the vendor specific error code will
+ * initialized to 0.
*/
- public BatchUpdateException(String message, String state, int vendorCode,
- int[] updateCounts)
+ public BatchUpdateException()
{
- super(message, state, vendorCode);
- this.updateCounts = updateCounts;
+ super();
}
/**
- * Get the update count information for this error. If not
- * <code>null</code>, this is an array of <code>int</code>'s that are
+ * This method returns the update count information for this error. If
+ * not <code>null</code> this is an array of <code>int</code>'s that are
* the update accounts for each command that was successfully executed.
* The array elements are in the order that the commands were executed.
*
- * @return the update count information, which may be <code>null</code>
+ * @return The update count information, which may be <code>null</code>.
*/
public int[] getUpdateCounts()
{
return updateCounts;
}
-} // class BatchUpdateException
+}
@@ -35,113 +35,107 @@ this exception to your version of the library, but you are not
/**
- * Create a new instance with no descriptive error message. The SQL state
- * and update count will be initialized to <code>null</code> and the
- * vendor specific error code will initialized to 0.
+ * This method initializes a new instance of <code>BatchUpdateException</code>
+ * with the specified descriptive error message, SQL state, and update count
+ * information. The vendor specific error code will be initialized to 0.
+ *
+ * @param message The descriptive error message.
+ * @param SQLState The SQL state information for this error.
+ * @param vendorCode
+ * @param updateCounts The update count information for this error.
*/